Trait tfdeploy::analyser::types::Fact[][src]

pub trait Fact: Debug + Clone + PartialEq + Default {
    type Concrete: Debug;
    fn concretize(&self) -> Option<Self::Concrete>;
fn unify(&self, other: &Self) -> Result<Self>; fn is_concrete(&self) -> bool { ... } }

Partial information about any value.

Associated Types

Required Methods

Tries to transform the fact into a concrete value.

Tries to unify the fact with another fact of the same type.

Provided Methods

Returns whether the value is fully determined.

Implementors