Struct tfdeploy::ops::konst::Const [−][src]
pub struct Const { /* fields omitted */ }Methods
impl Const[src]
impl ConstTrait Implementations
impl Debug for Const[src]
impl Debug for Constfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Clone for Const[src]
impl Clone for Constfn clone(&self) -> Const[src]
fn clone(&self) -> ConstReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Op for Const[src]
impl Op for Constfn eval(&self, _inputs: TVec<Value>) -> Result<TVec<Value>>[src]
fn eval(&self, _inputs: TVec<Value>) -> Result<TVec<Value>>Evaluates the operation given the input tensors.
fn get_attributes(&self) -> HashMap<&'static str, Attr>[src]
fn get_attributes(&self) -> HashMap<&'static str, Attr>Returns the attributes of the operation and their values.
fn const_value(&self) -> Option<Value>[src]
fn const_value(&self) -> Option<Value>ⓘImportant traits for Box<R>fn new_buffer(&self) -> Box<OpBuffer>[src]
ⓘImportant traits for Box<R>
fn new_buffer(&self) -> Box<OpBuffer>Returns a new streaming buffer for the operation.
fn step(
&self,
_inputs: TVec<StepValue>,
_buffer: &mut Box<OpBuffer>
) -> Result<Option<TVec<Value>>>[src]
fn step(
&self,
_inputs: TVec<StepValue>,
_buffer: &mut Box<OpBuffer>
) -> Result<Option<TVec<Value>>>Evaluates one step of the operation on the given input tensors. This is only implemented for operators which support streaming. Read more
fn infer_and_propagate(
&self,
inputs: TVec<TensorFact>,
outputs: TVec<TensorFact>
) -> Result<(TVec<TensorFact>, TVec<TensorFact>)>[src]
fn infer_and_propagate(
&self,
inputs: TVec<TensorFact>,
outputs: TVec<TensorFact>
) -> Result<(TVec<TensorFact>, TVec<TensorFact>)>Infers properties about the input and output tensors. Read more
fn final_prep(
&self,
_inputs: TVec<TensorFact>,
_outputs: TVec<TensorFact>
) -> Result<Option<Box<Op>>>[src]
fn final_prep(
&self,
_inputs: TVec<TensorFact>,
_outputs: TVec<TensorFact>
) -> Result<Option<Box<Op>>>fn rounding_errors(&self) -> bool[src]
fn rounding_errors(&self) -> boolimpl InferenceRulesOp for Const[src]
impl InferenceRulesOp for Constfn rules<'r, 'p: 'r, 's: 'r>(
&'s self,
solver: &mut Solver<'r>,
inputs: &'p TensorsProxy,
outputs: &'p TensorsProxy
)[src]
fn rules<'r, 'p: 'r, 's: 'r>(
&'s self,
solver: &mut Solver<'r>,
inputs: &'p TensorsProxy,
outputs: &'p TensorsProxy
)Registers the inference rules of the operator.